# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SecurityGroupAclArgs', 'SecurityGroupAcl']

@pulumi.input_type
class SecurityGroupAclArgs:
    def __init__(__self__, *,
                 acl_content: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 read_only: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a SecurityGroupAcl resource.
        :param pulumi.Input[builtins.str] acl_content: Content of ACL
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] ip_version: IP Version - Choices: `IPV4`, `IPV6`, `IP_AGNOSTIC` - Default value: `IP_AGNOSTIC`
        :param pulumi.Input[builtins.str] name: The name of the security group ACL
        :param pulumi.Input[builtins.bool] read_only: Read-only
        """
        pulumi.set(__self__, "acl_content", acl_content)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if read_only is not None:
            pulumi.set(__self__, "read_only", read_only)

    @property
    @pulumi.getter(name="aclContent")
    def acl_content(self) -> pulumi.Input[builtins.str]:
        """
        Content of ACL
        """
        return pulumi.get(self, "acl_content")

    @acl_content.setter
    def acl_content(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "acl_content", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP Version - Choices: `IPV4`, `IPV6`, `IP_AGNOSTIC` - Default value: `IP_AGNOSTIC`
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the security group ACL
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Read-only
        """
        return pulumi.get(self, "read_only")

    @read_only.setter
    def read_only(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "read_only", value)


@pulumi.input_type
class _SecurityGroupAclState:
    def __init__(__self__, *,
                 acl_content: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 read_only: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering SecurityGroupAcl resources.
        :param pulumi.Input[builtins.str] acl_content: Content of ACL
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] ip_version: IP Version - Choices: `IPV4`, `IPV6`, `IP_AGNOSTIC` - Default value: `IP_AGNOSTIC`
        :param pulumi.Input[builtins.str] name: The name of the security group ACL
        :param pulumi.Input[builtins.bool] read_only: Read-only
        """
        if acl_content is not None:
            pulumi.set(__self__, "acl_content", acl_content)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if read_only is not None:
            pulumi.set(__self__, "read_only", read_only)

    @property
    @pulumi.getter(name="aclContent")
    def acl_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Content of ACL
        """
        return pulumi.get(self, "acl_content")

    @acl_content.setter
    def acl_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "acl_content", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP Version - Choices: `IPV4`, `IPV6`, `IP_AGNOSTIC` - Default value: `IP_AGNOSTIC`
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the security group ACL
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Read-only
        """
        return pulumi.get(self, "read_only")

    @read_only.setter
    def read_only(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "read_only", value)


class SecurityGroupAcl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_content: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 read_only: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        This resource can manage a TrustSec Security Group ACL.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.trustsec.SecurityGroupAcl("example",
            name="ACL1",
            description="SG ACL 1",
            acl_content="Permit IP",
            ip_version="IPV4",
            read_only=False)
        ```

        ## Import

        ```sh
        $ pulumi import ise:trustsec/securityGroupAcl:SecurityGroupAcl example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] acl_content: Content of ACL
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] ip_version: IP Version - Choices: `IPV4`, `IPV6`, `IP_AGNOSTIC` - Default value: `IP_AGNOSTIC`
        :param pulumi.Input[builtins.str] name: The name of the security group ACL
        :param pulumi.Input[builtins.bool] read_only: Read-only
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecurityGroupAclArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a TrustSec Security Group ACL.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.trustsec.SecurityGroupAcl("example",
            name="ACL1",
            description="SG ACL 1",
            acl_content="Permit IP",
            ip_version="IPV4",
            read_only=False)
        ```

        ## Import

        ```sh
        $ pulumi import ise:trustsec/securityGroupAcl:SecurityGroupAcl example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param SecurityGroupAclArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityGroupAclArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 acl_content: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 read_only: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityGroupAclArgs.__new__(SecurityGroupAclArgs)

            if acl_content is None and not opts.urn:
                raise TypeError("Missing required property 'acl_content'")
            __props__.__dict__["acl_content"] = acl_content
            __props__.__dict__["description"] = description
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["name"] = name
            __props__.__dict__["read_only"] = read_only
        super(SecurityGroupAcl, __self__).__init__(
            'ise:trustsec/securityGroupAcl:SecurityGroupAcl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            acl_content: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ip_version: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            read_only: Optional[pulumi.Input[builtins.bool]] = None) -> 'SecurityGroupAcl':
        """
        Get an existing SecurityGroupAcl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] acl_content: Content of ACL
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] ip_version: IP Version - Choices: `IPV4`, `IPV6`, `IP_AGNOSTIC` - Default value: `IP_AGNOSTIC`
        :param pulumi.Input[builtins.str] name: The name of the security group ACL
        :param pulumi.Input[builtins.bool] read_only: Read-only
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityGroupAclState.__new__(_SecurityGroupAclState)

        __props__.__dict__["acl_content"] = acl_content
        __props__.__dict__["description"] = description
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["name"] = name
        __props__.__dict__["read_only"] = read_only
        return SecurityGroupAcl(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="aclContent")
    def acl_content(self) -> pulumi.Output[builtins.str]:
        """
        Content of ACL
        """
        return pulumi.get(self, "acl_content")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[builtins.str]:
        """
        IP Version - Choices: `IPV4`, `IPV6`, `IP_AGNOSTIC` - Default value: `IP_AGNOSTIC`
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the security group ACL
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Read-only
        """
        return pulumi.get(self, "read_only")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InternalUserArgs', 'InternalUser']

@pulumi.input_type
class InternalUserArgs:
    def __init__(__self__, *,
                 password: pulumi.Input[builtins.str],
                 account_name_alias: Optional[pulumi.Input[builtins.str]] = None,
                 change_password: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 enable_password: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 first_name: Optional[pulumi.Input[builtins.str]] = None,
                 identity_groups: Optional[pulumi.Input[builtins.str]] = None,
                 last_name: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password_id_store: Optional[pulumi.Input[builtins.str]] = None,
                 password_never_expires: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a InternalUser resource.
        :param pulumi.Input[builtins.str] password: The password of the internal user
        :param pulumi.Input[builtins.str] account_name_alias: The Account Name Alias will be used to send email notifications about password expiration. This field is only supported
               from ISE 3.2.
        :param pulumi.Input[builtins.bool] change_password: Requires the user to change the password - Default value: `true`
        :param pulumi.Input[builtins.str] custom_attributes: Key value map
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] email: Email address
        :param pulumi.Input[builtins.str] enable_password: This field is added in ISE 2.0 to support TACACS+
        :param pulumi.Input[builtins.bool] enabled: Whether the user is enabled/disabled
        :param pulumi.Input[builtins.str] first_name: First name of the internal user
        :param pulumi.Input[builtins.str] identity_groups: Comma separated list of identity group IDs.
        :param pulumi.Input[builtins.str] last_name: Last name of the internal user
        :param pulumi.Input[builtins.str] name: The name of the internal user
        :param pulumi.Input[builtins.str] password_id_store: The ID store where the internal user's password is kept - Default value: `Internal Users`
        :param pulumi.Input[builtins.bool] password_never_expires: Set to `true` to indicate the user password never expires. This will not apply to Users who are also ISE Admins. This
               field is only supported from ISE 3.2. - Default value: `false`
        """
        pulumi.set(__self__, "password", password)
        if account_name_alias is not None:
            pulumi.set(__self__, "account_name_alias", account_name_alias)
        if change_password is not None:
            pulumi.set(__self__, "change_password", change_password)
        if custom_attributes is not None:
            pulumi.set(__self__, "custom_attributes", custom_attributes)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if enable_password is not None:
            pulumi.set(__self__, "enable_password", enable_password)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if identity_groups is not None:
            pulumi.set(__self__, "identity_groups", identity_groups)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password_id_store is not None:
            pulumi.set(__self__, "password_id_store", password_id_store)
        if password_never_expires is not None:
            pulumi.set(__self__, "password_never_expires", password_never_expires)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[builtins.str]:
        """
        The password of the internal user
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="accountNameAlias")
    def account_name_alias(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Account Name Alias will be used to send email notifications about password expiration. This field is only supported
        from ISE 3.2.
        """
        return pulumi.get(self, "account_name_alias")

    @account_name_alias.setter
    def account_name_alias(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name_alias", value)

    @property
    @pulumi.getter(name="changePassword")
    def change_password(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Requires the user to change the password - Default value: `true`
        """
        return pulumi.get(self, "change_password")

    @change_password.setter
    def change_password(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "change_password", value)

    @property
    @pulumi.getter(name="customAttributes")
    def custom_attributes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Key value map
        """
        return pulumi.get(self, "custom_attributes")

    @custom_attributes.setter
    def custom_attributes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_attributes", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Email address
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="enablePassword")
    def enable_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        This field is added in ISE 2.0 to support TACACS+
        """
        return pulumi.get(self, "enable_password")

    @enable_password.setter
    def enable_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable_password", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the user is enabled/disabled
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        First name of the internal user
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="identityGroups")
    def identity_groups(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Comma separated list of identity group IDs.
        """
        return pulumi.get(self, "identity_groups")

    @identity_groups.setter
    def identity_groups(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "identity_groups", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Last name of the internal user
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the internal user
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="passwordIdStore")
    def password_id_store(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID store where the internal user's password is kept - Default value: `Internal Users`
        """
        return pulumi.get(self, "password_id_store")

    @password_id_store.setter
    def password_id_store(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password_id_store", value)

    @property
    @pulumi.getter(name="passwordNeverExpires")
    def password_never_expires(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to `true` to indicate the user password never expires. This will not apply to Users who are also ISE Admins. This
        field is only supported from ISE 3.2. - Default value: `false`
        """
        return pulumi.get(self, "password_never_expires")

    @password_never_expires.setter
    def password_never_expires(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "password_never_expires", value)


@pulumi.input_type
class _InternalUserState:
    def __init__(__self__, *,
                 account_name_alias: Optional[pulumi.Input[builtins.str]] = None,
                 change_password: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 enable_password: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 first_name: Optional[pulumi.Input[builtins.str]] = None,
                 identity_groups: Optional[pulumi.Input[builtins.str]] = None,
                 last_name: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 password_id_store: Optional[pulumi.Input[builtins.str]] = None,
                 password_never_expires: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering InternalUser resources.
        :param pulumi.Input[builtins.str] account_name_alias: The Account Name Alias will be used to send email notifications about password expiration. This field is only supported
               from ISE 3.2.
        :param pulumi.Input[builtins.bool] change_password: Requires the user to change the password - Default value: `true`
        :param pulumi.Input[builtins.str] custom_attributes: Key value map
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] email: Email address
        :param pulumi.Input[builtins.str] enable_password: This field is added in ISE 2.0 to support TACACS+
        :param pulumi.Input[builtins.bool] enabled: Whether the user is enabled/disabled
        :param pulumi.Input[builtins.str] first_name: First name of the internal user
        :param pulumi.Input[builtins.str] identity_groups: Comma separated list of identity group IDs.
        :param pulumi.Input[builtins.str] last_name: Last name of the internal user
        :param pulumi.Input[builtins.str] name: The name of the internal user
        :param pulumi.Input[builtins.str] password: The password of the internal user
        :param pulumi.Input[builtins.str] password_id_store: The ID store where the internal user's password is kept - Default value: `Internal Users`
        :param pulumi.Input[builtins.bool] password_never_expires: Set to `true` to indicate the user password never expires. This will not apply to Users who are also ISE Admins. This
               field is only supported from ISE 3.2. - Default value: `false`
        """
        if account_name_alias is not None:
            pulumi.set(__self__, "account_name_alias", account_name_alias)
        if change_password is not None:
            pulumi.set(__self__, "change_password", change_password)
        if custom_attributes is not None:
            pulumi.set(__self__, "custom_attributes", custom_attributes)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if enable_password is not None:
            pulumi.set(__self__, "enable_password", enable_password)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if identity_groups is not None:
            pulumi.set(__self__, "identity_groups", identity_groups)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_id_store is not None:
            pulumi.set(__self__, "password_id_store", password_id_store)
        if password_never_expires is not None:
            pulumi.set(__self__, "password_never_expires", password_never_expires)

    @property
    @pulumi.getter(name="accountNameAlias")
    def account_name_alias(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Account Name Alias will be used to send email notifications about password expiration. This field is only supported
        from ISE 3.2.
        """
        return pulumi.get(self, "account_name_alias")

    @account_name_alias.setter
    def account_name_alias(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name_alias", value)

    @property
    @pulumi.getter(name="changePassword")
    def change_password(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Requires the user to change the password - Default value: `true`
        """
        return pulumi.get(self, "change_password")

    @change_password.setter
    def change_password(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "change_password", value)

    @property
    @pulumi.getter(name="customAttributes")
    def custom_attributes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Key value map
        """
        return pulumi.get(self, "custom_attributes")

    @custom_attributes.setter
    def custom_attributes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_attributes", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Email address
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="enablePassword")
    def enable_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        This field is added in ISE 2.0 to support TACACS+
        """
        return pulumi.get(self, "enable_password")

    @enable_password.setter
    def enable_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable_password", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the user is enabled/disabled
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        First name of the internal user
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="identityGroups")
    def identity_groups(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Comma separated list of identity group IDs.
        """
        return pulumi.get(self, "identity_groups")

    @identity_groups.setter
    def identity_groups(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "identity_groups", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Last name of the internal user
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the internal user
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The password of the internal user
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="passwordIdStore")
    def password_id_store(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID store where the internal user's password is kept - Default value: `Internal Users`
        """
        return pulumi.get(self, "password_id_store")

    @password_id_store.setter
    def password_id_store(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password_id_store", value)

    @property
    @pulumi.getter(name="passwordNeverExpires")
    def password_never_expires(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to `true` to indicate the user password never expires. This will not apply to Users who are also ISE Admins. This
        field is only supported from ISE 3.2. - Default value: `false`
        """
        return pulumi.get(self, "password_never_expires")

    @password_never_expires.setter
    def password_never_expires(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "password_never_expires", value)


class InternalUser(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name_alias: Optional[pulumi.Input[builtins.str]] = None,
                 change_password: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 enable_password: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 first_name: Optional[pulumi.Input[builtins.str]] = None,
                 identity_groups: Optional[pulumi.Input[builtins.str]] = None,
                 last_name: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 password_id_store: Optional[pulumi.Input[builtins.str]] = None,
                 password_never_expires: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        This resource can manage an Internal User.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.InternalUser("example",
            name="UserTF",
            password="Cisco123",
            change_password=True,
            email="aaa@cisco.com",
            account_name_alias="User 1",
            enable_password="Cisco123",
            enabled=True,
            password_never_expires=False,
            first_name="John",
            last_name="Doe",
            password_id_store="Internal Users",
            description="My first Terraform user")
        ```

        ## Import

        ```sh
        $ pulumi import ise:identitymanagement/internalUser:InternalUser example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_name_alias: The Account Name Alias will be used to send email notifications about password expiration. This field is only supported
               from ISE 3.2.
        :param pulumi.Input[builtins.bool] change_password: Requires the user to change the password - Default value: `true`
        :param pulumi.Input[builtins.str] custom_attributes: Key value map
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] email: Email address
        :param pulumi.Input[builtins.str] enable_password: This field is added in ISE 2.0 to support TACACS+
        :param pulumi.Input[builtins.bool] enabled: Whether the user is enabled/disabled
        :param pulumi.Input[builtins.str] first_name: First name of the internal user
        :param pulumi.Input[builtins.str] identity_groups: Comma separated list of identity group IDs.
        :param pulumi.Input[builtins.str] last_name: Last name of the internal user
        :param pulumi.Input[builtins.str] name: The name of the internal user
        :param pulumi.Input[builtins.str] password: The password of the internal user
        :param pulumi.Input[builtins.str] password_id_store: The ID store where the internal user's password is kept - Default value: `Internal Users`
        :param pulumi.Input[builtins.bool] password_never_expires: Set to `true` to indicate the user password never expires. This will not apply to Users who are also ISE Admins. This
               field is only supported from ISE 3.2. - Default value: `false`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InternalUserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage an Internal User.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.identitymanagement.InternalUser("example",
            name="UserTF",
            password="Cisco123",
            change_password=True,
            email="aaa@cisco.com",
            account_name_alias="User 1",
            enable_password="Cisco123",
            enabled=True,
            password_never_expires=False,
            first_name="John",
            last_name="Doe",
            password_id_store="Internal Users",
            description="My first Terraform user")
        ```

        ## Import

        ```sh
        $ pulumi import ise:identitymanagement/internalUser:InternalUser example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param InternalUserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InternalUserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name_alias: Optional[pulumi.Input[builtins.str]] = None,
                 change_password: Optional[pulumi.Input[builtins.bool]] = None,
                 custom_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 email: Optional[pulumi.Input[builtins.str]] = None,
                 enable_password: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 first_name: Optional[pulumi.Input[builtins.str]] = None,
                 identity_groups: Optional[pulumi.Input[builtins.str]] = None,
                 last_name: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 password_id_store: Optional[pulumi.Input[builtins.str]] = None,
                 password_never_expires: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InternalUserArgs.__new__(InternalUserArgs)

            __props__.__dict__["account_name_alias"] = account_name_alias
            __props__.__dict__["change_password"] = change_password
            __props__.__dict__["custom_attributes"] = custom_attributes
            __props__.__dict__["description"] = description
            __props__.__dict__["email"] = email
            __props__.__dict__["enable_password"] = enable_password
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["first_name"] = first_name
            __props__.__dict__["identity_groups"] = identity_groups
            __props__.__dict__["last_name"] = last_name
            __props__.__dict__["name"] = name
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = password
            __props__.__dict__["password_id_store"] = password_id_store
            __props__.__dict__["password_never_expires"] = password_never_expires
        super(InternalUser, __self__).__init__(
            'ise:identitymanagement/internalUser:InternalUser',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_name_alias: Optional[pulumi.Input[builtins.str]] = None,
            change_password: Optional[pulumi.Input[builtins.bool]] = None,
            custom_attributes: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            email: Optional[pulumi.Input[builtins.str]] = None,
            enable_password: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            first_name: Optional[pulumi.Input[builtins.str]] = None,
            identity_groups: Optional[pulumi.Input[builtins.str]] = None,
            last_name: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            password_id_store: Optional[pulumi.Input[builtins.str]] = None,
            password_never_expires: Optional[pulumi.Input[builtins.bool]] = None) -> 'InternalUser':
        """
        Get an existing InternalUser resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_name_alias: The Account Name Alias will be used to send email notifications about password expiration. This field is only supported
               from ISE 3.2.
        :param pulumi.Input[builtins.bool] change_password: Requires the user to change the password - Default value: `true`
        :param pulumi.Input[builtins.str] custom_attributes: Key value map
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] email: Email address
        :param pulumi.Input[builtins.str] enable_password: This field is added in ISE 2.0 to support TACACS+
        :param pulumi.Input[builtins.bool] enabled: Whether the user is enabled/disabled
        :param pulumi.Input[builtins.str] first_name: First name of the internal user
        :param pulumi.Input[builtins.str] identity_groups: Comma separated list of identity group IDs.
        :param pulumi.Input[builtins.str] last_name: Last name of the internal user
        :param pulumi.Input[builtins.str] name: The name of the internal user
        :param pulumi.Input[builtins.str] password: The password of the internal user
        :param pulumi.Input[builtins.str] password_id_store: The ID store where the internal user's password is kept - Default value: `Internal Users`
        :param pulumi.Input[builtins.bool] password_never_expires: Set to `true` to indicate the user password never expires. This will not apply to Users who are also ISE Admins. This
               field is only supported from ISE 3.2. - Default value: `false`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InternalUserState.__new__(_InternalUserState)

        __props__.__dict__["account_name_alias"] = account_name_alias
        __props__.__dict__["change_password"] = change_password
        __props__.__dict__["custom_attributes"] = custom_attributes
        __props__.__dict__["description"] = description
        __props__.__dict__["email"] = email
        __props__.__dict__["enable_password"] = enable_password
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["first_name"] = first_name
        __props__.__dict__["identity_groups"] = identity_groups
        __props__.__dict__["last_name"] = last_name
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["password_id_store"] = password_id_store
        __props__.__dict__["password_never_expires"] = password_never_expires
        return InternalUser(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountNameAlias")
    def account_name_alias(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Account Name Alias will be used to send email notifications about password expiration. This field is only supported
        from ISE 3.2.
        """
        return pulumi.get(self, "account_name_alias")

    @property
    @pulumi.getter(name="changePassword")
    def change_password(self) -> pulumi.Output[builtins.bool]:
        """
        Requires the user to change the password - Default value: `true`
        """
        return pulumi.get(self, "change_password")

    @property
    @pulumi.getter(name="customAttributes")
    def custom_attributes(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Key value map
        """
        return pulumi.get(self, "custom_attributes")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Email address
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="enablePassword")
    def enable_password(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        This field is added in ISE 2.0 to support TACACS+
        """
        return pulumi.get(self, "enable_password")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether the user is enabled/disabled
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        First name of the internal user
        """
        return pulumi.get(self, "first_name")

    @property
    @pulumi.getter(name="identityGroups")
    def identity_groups(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Comma separated list of identity group IDs.
        """
        return pulumi.get(self, "identity_groups")

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Last name of the internal user
        """
        return pulumi.get(self, "last_name")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the internal user
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        The password of the internal user
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordIdStore")
    def password_id_store(self) -> pulumi.Output[builtins.str]:
        """
        The ID store where the internal user's password is kept - Default value: `Internal Users`
        """
        return pulumi.get(self, "password_id_store")

    @property
    @pulumi.getter(name="passwordNeverExpires")
    def password_never_expires(self) -> pulumi.Output[builtins.bool]:
        """
        Set to `true` to indicate the user password never expires. This will not apply to Users who are also ISE Admins. This
        field is only supported from ISE 3.2. - Default value: `false`
        """
        return pulumi.get(self, "password_never_expires")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .allowed_protocols_tacacs import *
from .authentication_rule import *
from .authentication_rule_update_rank import *
from .authorization_exception_rule import *
from .authorization_exception_rule_update_rank import *
from .authorization_global_exception_rule import *
from .authorization_global_exception_rule_update_rank import *
from .authorization_rule import *
from .authorization_rule_update_rank import *
from .condition import *
from .get_allowed_protocols_tacacs import *
from .get_authentication_rule import *
from .get_authorization_exception_rule import *
from .get_authorization_global_exception_rule import *
from .get_authorization_rule import *
from .get_condition import *
from .get_policy_set import *
from .get_tacacs_command_set import *
from .get_tacacs_profile import *
from .get_time_and_date_condition import *
from .policy_set import *
from .policy_set_update_rank import *
from .tacacs_command_set import *
from .tacacs_profile import *
from .time_and_date_condition import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTacacsProfileResult',
    'AwaitableGetTacacsProfileResult',
    'get_tacacs_profile',
    'get_tacacs_profile_output',
]

@pulumi.output_type
class GetTacacsProfileResult:
    """
    A collection of values returned by getTacacsProfile.
    """
    def __init__(__self__, description=None, id=None, name=None, session_attributes=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if session_attributes and not isinstance(session_attributes, list):
            raise TypeError("Expected argument 'session_attributes' to be a list")
        pulumi.set(__self__, "session_attributes", session_attributes)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the TACACS profile
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="sessionAttributes")
    def session_attributes(self) -> Sequence['outputs.GetTacacsProfileSessionAttributeResult']:
        return pulumi.get(self, "session_attributes")


class AwaitableGetTacacsProfileResult(GetTacacsProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTacacsProfileResult(
            description=self.description,
            id=self.id,
            name=self.name,
            session_attributes=self.session_attributes)


def get_tacacs_profile(id: Optional[builtins.str] = None,
                       name: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTacacsProfileResult:
    """
    This data source can read the TACACS Profile.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_tacacs_profile(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the TACACS profile
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:deviceadmin/getTacacsProfile:getTacacsProfile', __args__, opts=opts, typ=GetTacacsProfileResult).value

    return AwaitableGetTacacsProfileResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        session_attributes=pulumi.get(__ret__, 'session_attributes'))
def get_tacacs_profile_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTacacsProfileResult]:
    """
    This data source can read the TACACS Profile.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.deviceadmin.get_tacacs_profile(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the TACACS profile
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:deviceadmin/getTacacsProfile:getTacacsProfile', __args__, opts=opts, typ=GetTacacsProfileResult)
    return __ret__.apply(lambda __response__: GetTacacsProfileResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        session_attributes=pulumi.get(__response__, 'session_attributes')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDeviceResult',
    'AwaitableGetDeviceResult',
    'get_device',
    'get_device_output',
]

@pulumi.output_type
class GetDeviceResult:
    """
    A collection of values returned by getDevice.
    """
    def __init__(__self__, authentication_dtls_required=None, authentication_enable_key_wrap=None, authentication_enable_multi_secret=None, authentication_encryption_key=None, authentication_encryption_key_format=None, authentication_message_authenticator_code_key=None, authentication_network_protocol=None, authentication_radius_shared_secret=None, authentication_second_radius_shared_secret=None, coa_port=None, description=None, dtls_dns_name=None, id=None, ips=None, model_name=None, name=None, network_device_groups=None, profile_name=None, snmp_link_trap_query=None, snmp_mac_trap_query=None, snmp_originating_policy_service_node=None, snmp_polling_interval=None, snmp_ro_community=None, snmp_version=None, software_version=None, tacacs_connect_mode_options=None, tacacs_shared_secret=None, trustsec_coa_source_host=None, trustsec_device_id=None, trustsec_device_password=None, trustsec_download_enviroment_data_every_x_seconds=None, trustsec_download_peer_authorization_policy_every_x_seconds=None, trustsec_download_sgacl_lists_every_x_seconds=None, trustsec_enable_mode_password=None, trustsec_exec_mode_password=None, trustsec_exec_mode_username=None, trustsec_include_when_deploying_sgt_updates=None, trustsec_other_sga_devices_to_trust_this_device=None, trustsec_re_authentication_every_x_seconds=None, trustsec_rest_api_password=None, trustsec_rest_api_username=None, trustsec_send_configuration_to_device=None, trustsec_send_configuration_to_device_using=None):
        if authentication_dtls_required and not isinstance(authentication_dtls_required, bool):
            raise TypeError("Expected argument 'authentication_dtls_required' to be a bool")
        pulumi.set(__self__, "authentication_dtls_required", authentication_dtls_required)
        if authentication_enable_key_wrap and not isinstance(authentication_enable_key_wrap, bool):
            raise TypeError("Expected argument 'authentication_enable_key_wrap' to be a bool")
        pulumi.set(__self__, "authentication_enable_key_wrap", authentication_enable_key_wrap)
        if authentication_enable_multi_secret and not isinstance(authentication_enable_multi_secret, bool):
            raise TypeError("Expected argument 'authentication_enable_multi_secret' to be a bool")
        pulumi.set(__self__, "authentication_enable_multi_secret", authentication_enable_multi_secret)
        if authentication_encryption_key and not isinstance(authentication_encryption_key, str):
            raise TypeError("Expected argument 'authentication_encryption_key' to be a str")
        pulumi.set(__self__, "authentication_encryption_key", authentication_encryption_key)
        if authentication_encryption_key_format and not isinstance(authentication_encryption_key_format, str):
            raise TypeError("Expected argument 'authentication_encryption_key_format' to be a str")
        pulumi.set(__self__, "authentication_encryption_key_format", authentication_encryption_key_format)
        if authentication_message_authenticator_code_key and not isinstance(authentication_message_authenticator_code_key, str):
            raise TypeError("Expected argument 'authentication_message_authenticator_code_key' to be a str")
        pulumi.set(__self__, "authentication_message_authenticator_code_key", authentication_message_authenticator_code_key)
        if authentication_network_protocol and not isinstance(authentication_network_protocol, str):
            raise TypeError("Expected argument 'authentication_network_protocol' to be a str")
        pulumi.set(__self__, "authentication_network_protocol", authentication_network_protocol)
        if authentication_radius_shared_secret and not isinstance(authentication_radius_shared_secret, str):
            raise TypeError("Expected argument 'authentication_radius_shared_secret' to be a str")
        pulumi.set(__self__, "authentication_radius_shared_secret", authentication_radius_shared_secret)
        if authentication_second_radius_shared_secret and not isinstance(authentication_second_radius_shared_secret, str):
            raise TypeError("Expected argument 'authentication_second_radius_shared_secret' to be a str")
        pulumi.set(__self__, "authentication_second_radius_shared_secret", authentication_second_radius_shared_secret)
        if coa_port and not isinstance(coa_port, int):
            raise TypeError("Expected argument 'coa_port' to be a int")
        pulumi.set(__self__, "coa_port", coa_port)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if dtls_dns_name and not isinstance(dtls_dns_name, str):
            raise TypeError("Expected argument 'dtls_dns_name' to be a str")
        pulumi.set(__self__, "dtls_dns_name", dtls_dns_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ips and not isinstance(ips, list):
            raise TypeError("Expected argument 'ips' to be a list")
        pulumi.set(__self__, "ips", ips)
        if model_name and not isinstance(model_name, str):
            raise TypeError("Expected argument 'model_name' to be a str")
        pulumi.set(__self__, "model_name", model_name)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_device_groups and not isinstance(network_device_groups, list):
            raise TypeError("Expected argument 'network_device_groups' to be a list")
        pulumi.set(__self__, "network_device_groups", network_device_groups)
        if profile_name and not isinstance(profile_name, str):
            raise TypeError("Expected argument 'profile_name' to be a str")
        pulumi.set(__self__, "profile_name", profile_name)
        if snmp_link_trap_query and not isinstance(snmp_link_trap_query, bool):
            raise TypeError("Expected argument 'snmp_link_trap_query' to be a bool")
        pulumi.set(__self__, "snmp_link_trap_query", snmp_link_trap_query)
        if snmp_mac_trap_query and not isinstance(snmp_mac_trap_query, bool):
            raise TypeError("Expected argument 'snmp_mac_trap_query' to be a bool")
        pulumi.set(__self__, "snmp_mac_trap_query", snmp_mac_trap_query)
        if snmp_originating_policy_service_node and not isinstance(snmp_originating_policy_service_node, str):
            raise TypeError("Expected argument 'snmp_originating_policy_service_node' to be a str")
        pulumi.set(__self__, "snmp_originating_policy_service_node", snmp_originating_policy_service_node)
        if snmp_polling_interval and not isinstance(snmp_polling_interval, int):
            raise TypeError("Expected argument 'snmp_polling_interval' to be a int")
        pulumi.set(__self__, "snmp_polling_interval", snmp_polling_interval)
        if snmp_ro_community and not isinstance(snmp_ro_community, str):
            raise TypeError("Expected argument 'snmp_ro_community' to be a str")
        pulumi.set(__self__, "snmp_ro_community", snmp_ro_community)
        if snmp_version and not isinstance(snmp_version, str):
            raise TypeError("Expected argument 'snmp_version' to be a str")
        pulumi.set(__self__, "snmp_version", snmp_version)
        if software_version and not isinstance(software_version, str):
            raise TypeError("Expected argument 'software_version' to be a str")
        pulumi.set(__self__, "software_version", software_version)
        if tacacs_connect_mode_options and not isinstance(tacacs_connect_mode_options, str):
            raise TypeError("Expected argument 'tacacs_connect_mode_options' to be a str")
        pulumi.set(__self__, "tacacs_connect_mode_options", tacacs_connect_mode_options)
        if tacacs_shared_secret and not isinstance(tacacs_shared_secret, str):
            raise TypeError("Expected argument 'tacacs_shared_secret' to be a str")
        pulumi.set(__self__, "tacacs_shared_secret", tacacs_shared_secret)
        if trustsec_coa_source_host and not isinstance(trustsec_coa_source_host, str):
            raise TypeError("Expected argument 'trustsec_coa_source_host' to be a str")
        pulumi.set(__self__, "trustsec_coa_source_host", trustsec_coa_source_host)
        if trustsec_device_id and not isinstance(trustsec_device_id, str):
            raise TypeError("Expected argument 'trustsec_device_id' to be a str")
        pulumi.set(__self__, "trustsec_device_id", trustsec_device_id)
        if trustsec_device_password and not isinstance(trustsec_device_password, str):
            raise TypeError("Expected argument 'trustsec_device_password' to be a str")
        pulumi.set(__self__, "trustsec_device_password", trustsec_device_password)
        if trustsec_download_enviroment_data_every_x_seconds and not isinstance(trustsec_download_enviroment_data_every_x_seconds, int):
            raise TypeError("Expected argument 'trustsec_download_enviroment_data_every_x_seconds' to be a int")
        pulumi.set(__self__, "trustsec_download_enviroment_data_every_x_seconds", trustsec_download_enviroment_data_every_x_seconds)
        if trustsec_download_peer_authorization_policy_every_x_seconds and not isinstance(trustsec_download_peer_authorization_policy_every_x_seconds, int):
            raise TypeError("Expected argument 'trustsec_download_peer_authorization_policy_every_x_seconds' to be a int")
        pulumi.set(__self__, "trustsec_download_peer_authorization_policy_every_x_seconds", trustsec_download_peer_authorization_policy_every_x_seconds)
        if trustsec_download_sgacl_lists_every_x_seconds and not isinstance(trustsec_download_sgacl_lists_every_x_seconds, int):
            raise TypeError("Expected argument 'trustsec_download_sgacl_lists_every_x_seconds' to be a int")
        pulumi.set(__self__, "trustsec_download_sgacl_lists_every_x_seconds", trustsec_download_sgacl_lists_every_x_seconds)
        if trustsec_enable_mode_password and not isinstance(trustsec_enable_mode_password, str):
            raise TypeError("Expected argument 'trustsec_enable_mode_password' to be a str")
        pulumi.set(__self__, "trustsec_enable_mode_password", trustsec_enable_mode_password)
        if trustsec_exec_mode_password and not isinstance(trustsec_exec_mode_password, str):
            raise TypeError("Expected argument 'trustsec_exec_mode_password' to be a str")
        pulumi.set(__self__, "trustsec_exec_mode_password", trustsec_exec_mode_password)
        if trustsec_exec_mode_username and not isinstance(trustsec_exec_mode_username, str):
            raise TypeError("Expected argument 'trustsec_exec_mode_username' to be a str")
        pulumi.set(__self__, "trustsec_exec_mode_username", trustsec_exec_mode_username)
        if trustsec_include_when_deploying_sgt_updates and not isinstance(trustsec_include_when_deploying_sgt_updates, bool):
            raise TypeError("Expected argument 'trustsec_include_when_deploying_sgt_updates' to be a bool")
        pulumi.set(__self__, "trustsec_include_when_deploying_sgt_updates", trustsec_include_when_deploying_sgt_updates)
        if trustsec_other_sga_devices_to_trust_this_device and not isinstance(trustsec_other_sga_devices_to_trust_this_device, bool):
            raise TypeError("Expected argument 'trustsec_other_sga_devices_to_trust_this_device' to be a bool")
        pulumi.set(__self__, "trustsec_other_sga_devices_to_trust_this_device", trustsec_other_sga_devices_to_trust_this_device)
        if trustsec_re_authentication_every_x_seconds and not isinstance(trustsec_re_authentication_every_x_seconds, int):
            raise TypeError("Expected argument 'trustsec_re_authentication_every_x_seconds' to be a int")
        pulumi.set(__self__, "trustsec_re_authentication_every_x_seconds", trustsec_re_authentication_every_x_seconds)
        if trustsec_rest_api_password and not isinstance(trustsec_rest_api_password, str):
            raise TypeError("Expected argument 'trustsec_rest_api_password' to be a str")
        pulumi.set(__self__, "trustsec_rest_api_password", trustsec_rest_api_password)
        if trustsec_rest_api_username and not isinstance(trustsec_rest_api_username, str):
            raise TypeError("Expected argument 'trustsec_rest_api_username' to be a str")
        pulumi.set(__self__, "trustsec_rest_api_username", trustsec_rest_api_username)
        if trustsec_send_configuration_to_device and not isinstance(trustsec_send_configuration_to_device, bool):
            raise TypeError("Expected argument 'trustsec_send_configuration_to_device' to be a bool")
        pulumi.set(__self__, "trustsec_send_configuration_to_device", trustsec_send_configuration_to_device)
        if trustsec_send_configuration_to_device_using and not isinstance(trustsec_send_configuration_to_device_using, str):
            raise TypeError("Expected argument 'trustsec_send_configuration_to_device_using' to be a str")
        pulumi.set(__self__, "trustsec_send_configuration_to_device_using", trustsec_send_configuration_to_device_using)

    @property
    @pulumi.getter(name="authenticationDtlsRequired")
    def authentication_dtls_required(self) -> builtins.bool:
        """
        Enforce use of DTLS
        """
        return pulumi.get(self, "authentication_dtls_required")

    @property
    @pulumi.getter(name="authenticationEnableKeyWrap")
    def authentication_enable_key_wrap(self) -> builtins.bool:
        """
        Enable key wrap
        """
        return pulumi.get(self, "authentication_enable_key_wrap")

    @property
    @pulumi.getter(name="authenticationEnableMultiSecret")
    def authentication_enable_multi_secret(self) -> builtins.bool:
        """
        Enable multiple RADIUS shared secrets
        """
        return pulumi.get(self, "authentication_enable_multi_secret")

    @property
    @pulumi.getter(name="authenticationEncryptionKey")
    def authentication_encryption_key(self) -> builtins.str:
        """
        Encryption key
        """
        return pulumi.get(self, "authentication_encryption_key")

    @property
    @pulumi.getter(name="authenticationEncryptionKeyFormat")
    def authentication_encryption_key_format(self) -> builtins.str:
        """
        Key input format
        """
        return pulumi.get(self, "authentication_encryption_key_format")

    @property
    @pulumi.getter(name="authenticationMessageAuthenticatorCodeKey")
    def authentication_message_authenticator_code_key(self) -> builtins.str:
        """
        Message authenticator code key
        """
        return pulumi.get(self, "authentication_message_authenticator_code_key")

    @property
    @pulumi.getter(name="authenticationNetworkProtocol")
    def authentication_network_protocol(self) -> builtins.str:
        """
        Network protocol
        """
        return pulumi.get(self, "authentication_network_protocol")

    @property
    @pulumi.getter(name="authenticationRadiusSharedSecret")
    def authentication_radius_shared_secret(self) -> builtins.str:
        """
        RADIUS shared secret
        """
        return pulumi.get(self, "authentication_radius_shared_secret")

    @property
    @pulumi.getter(name="authenticationSecondRadiusSharedSecret")
    def authentication_second_radius_shared_secret(self) -> builtins.str:
        """
        Second RADIUS shared secret
        """
        return pulumi.get(self, "authentication_second_radius_shared_secret")

    @property
    @pulumi.getter(name="coaPort")
    def coa_port(self) -> builtins.int:
        """
        CoA port
        """
        return pulumi.get(self, "coa_port")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dtlsDnsName")
    def dtls_dns_name(self) -> builtins.str:
        """
        This value is used to verify the client identity contained in the X.509 RADIUS/DTLS client certificate
        """
        return pulumi.get(self, "dtls_dns_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ips(self) -> Sequence['outputs.GetDeviceIpResult']:
        """
        List of IP subnets
        """
        return pulumi.get(self, "ips")

    @property
    @pulumi.getter(name="modelName")
    def model_name(self) -> builtins.str:
        """
        Model name
        """
        return pulumi.get(self, "model_name")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the network device
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkDeviceGroups")
    def network_device_groups(self) -> Sequence[builtins.str]:
        """
        List of network device groups, e.g. `Device Type#All Device Types#ACCESS`
        """
        return pulumi.get(self, "network_device_groups")

    @property
    @pulumi.getter(name="profileName")
    def profile_name(self) -> builtins.str:
        """
        Profile name
        """
        return pulumi.get(self, "profile_name")

    @property
    @pulumi.getter(name="snmpLinkTrapQuery")
    def snmp_link_trap_query(self) -> builtins.bool:
        """
        SNMP link Trap Query
        """
        return pulumi.get(self, "snmp_link_trap_query")

    @property
    @pulumi.getter(name="snmpMacTrapQuery")
    def snmp_mac_trap_query(self) -> builtins.bool:
        """
        SNMP MAC Trap Query
        """
        return pulumi.get(self, "snmp_mac_trap_query")

    @property
    @pulumi.getter(name="snmpOriginatingPolicyServiceNode")
    def snmp_originating_policy_service_node(self) -> builtins.str:
        """
        Originating Policy Services Node
        """
        return pulumi.get(self, "snmp_originating_policy_service_node")

    @property
    @pulumi.getter(name="snmpPollingInterval")
    def snmp_polling_interval(self) -> builtins.int:
        """
        SNMP Polling Interval in seconds
        """
        return pulumi.get(self, "snmp_polling_interval")

    @property
    @pulumi.getter(name="snmpRoCommunity")
    def snmp_ro_community(self) -> builtins.str:
        """
        SNMP RO Community
        """
        return pulumi.get(self, "snmp_ro_community")

    @property
    @pulumi.getter(name="snmpVersion")
    def snmp_version(self) -> builtins.str:
        """
        SNMP version
        """
        return pulumi.get(self, "snmp_version")

    @property
    @pulumi.getter(name="softwareVersion")
    def software_version(self) -> builtins.str:
        """
        Software version
        """
        return pulumi.get(self, "software_version")

    @property
    @pulumi.getter(name="tacacsConnectModeOptions")
    def tacacs_connect_mode_options(self) -> builtins.str:
        """
        Connect mode options
        """
        return pulumi.get(self, "tacacs_connect_mode_options")

    @property
    @pulumi.getter(name="tacacsSharedSecret")
    def tacacs_shared_secret(self) -> builtins.str:
        """
        Shared secret
        """
        return pulumi.get(self, "tacacs_shared_secret")

    @property
    @pulumi.getter(name="trustsecCoaSourceHost")
    def trustsec_coa_source_host(self) -> builtins.str:
        """
        CoA source host
        """
        return pulumi.get(self, "trustsec_coa_source_host")

    @property
    @pulumi.getter(name="trustsecDeviceId")
    def trustsec_device_id(self) -> builtins.str:
        """
        TrustSec device ID
        """
        return pulumi.get(self, "trustsec_device_id")

    @property
    @pulumi.getter(name="trustsecDevicePassword")
    def trustsec_device_password(self) -> builtins.str:
        """
        TrustSec device password
        """
        return pulumi.get(self, "trustsec_device_password")

    @property
    @pulumi.getter(name="trustsecDownloadEnviromentDataEveryXSeconds")
    def trustsec_download_enviroment_data_every_x_seconds(self) -> builtins.int:
        """
        Download environment data every X seconds
        """
        return pulumi.get(self, "trustsec_download_enviroment_data_every_x_seconds")

    @property
    @pulumi.getter(name="trustsecDownloadPeerAuthorizationPolicyEveryXSeconds")
    def trustsec_download_peer_authorization_policy_every_x_seconds(self) -> builtins.int:
        """
        Download peer authorization policy every X seconds
        """
        return pulumi.get(self, "trustsec_download_peer_authorization_policy_every_x_seconds")

    @property
    @pulumi.getter(name="trustsecDownloadSgaclListsEveryXSeconds")
    def trustsec_download_sgacl_lists_every_x_seconds(self) -> builtins.int:
        """
        Download SGACL lists every X seconds
        """
        return pulumi.get(self, "trustsec_download_sgacl_lists_every_x_seconds")

    @property
    @pulumi.getter(name="trustsecEnableModePassword")
    def trustsec_enable_mode_password(self) -> builtins.str:
        """
        Enable mode password
        """
        return pulumi.get(self, "trustsec_enable_mode_password")

    @property
    @pulumi.getter(name="trustsecExecModePassword")
    def trustsec_exec_mode_password(self) -> builtins.str:
        """
        EXEC mode password
        """
        return pulumi.get(self, "trustsec_exec_mode_password")

    @property
    @pulumi.getter(name="trustsecExecModeUsername")
    def trustsec_exec_mode_username(self) -> builtins.str:
        """
        EXEC mode username
        """
        return pulumi.get(self, "trustsec_exec_mode_username")

    @property
    @pulumi.getter(name="trustsecIncludeWhenDeployingSgtUpdates")
    def trustsec_include_when_deploying_sgt_updates(self) -> builtins.bool:
        """
        Include this device when deploying Security Group Tag Mapping Updates
        """
        return pulumi.get(self, "trustsec_include_when_deploying_sgt_updates")

    @property
    @pulumi.getter(name="trustsecOtherSgaDevicesToTrustThisDevice")
    def trustsec_other_sga_devices_to_trust_this_device(self) -> builtins.bool:
        """
        Other TrustSec devices to trust this device
        """
        return pulumi.get(self, "trustsec_other_sga_devices_to_trust_this_device")

    @property
    @pulumi.getter(name="trustsecReAuthenticationEveryXSeconds")
    def trustsec_re_authentication_every_x_seconds(self) -> builtins.int:
        """
        Re-authenticate every X seconds
        """
        return pulumi.get(self, "trustsec_re_authentication_every_x_seconds")

    @property
    @pulumi.getter(name="trustsecRestApiPassword")
    def trustsec_rest_api_password(self) -> builtins.str:
        """
        REST API password
        """
        return pulumi.get(self, "trustsec_rest_api_password")

    @property
    @pulumi.getter(name="trustsecRestApiUsername")
    def trustsec_rest_api_username(self) -> builtins.str:
        """
        REST API username
        """
        return pulumi.get(self, "trustsec_rest_api_username")

    @property
    @pulumi.getter(name="trustsecSendConfigurationToDevice")
    def trustsec_send_configuration_to_device(self) -> builtins.bool:
        """
        Send configuration to device
        """
        return pulumi.get(self, "trustsec_send_configuration_to_device")

    @property
    @pulumi.getter(name="trustsecSendConfigurationToDeviceUsing")
    def trustsec_send_configuration_to_device_using(self) -> builtins.str:
        """
        Send configuration to device using
        """
        return pulumi.get(self, "trustsec_send_configuration_to_device_using")


class AwaitableGetDeviceResult(GetDeviceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDeviceResult(
            authentication_dtls_required=self.authentication_dtls_required,
            authentication_enable_key_wrap=self.authentication_enable_key_wrap,
            authentication_enable_multi_secret=self.authentication_enable_multi_secret,
            authentication_encryption_key=self.authentication_encryption_key,
            authentication_encryption_key_format=self.authentication_encryption_key_format,
            authentication_message_authenticator_code_key=self.authentication_message_authenticator_code_key,
            authentication_network_protocol=self.authentication_network_protocol,
            authentication_radius_shared_secret=self.authentication_radius_shared_secret,
            authentication_second_radius_shared_secret=self.authentication_second_radius_shared_secret,
            coa_port=self.coa_port,
            description=self.description,
            dtls_dns_name=self.dtls_dns_name,
            id=self.id,
            ips=self.ips,
            model_name=self.model_name,
            name=self.name,
            network_device_groups=self.network_device_groups,
            profile_name=self.profile_name,
            snmp_link_trap_query=self.snmp_link_trap_query,
            snmp_mac_trap_query=self.snmp_mac_trap_query,
            snmp_originating_policy_service_node=self.snmp_originating_policy_service_node,
            snmp_polling_interval=self.snmp_polling_interval,
            snmp_ro_community=self.snmp_ro_community,
            snmp_version=self.snmp_version,
            software_version=self.software_version,
            tacacs_connect_mode_options=self.tacacs_connect_mode_options,
            tacacs_shared_secret=self.tacacs_shared_secret,
            trustsec_coa_source_host=self.trustsec_coa_source_host,
            trustsec_device_id=self.trustsec_device_id,
            trustsec_device_password=self.trustsec_device_password,
            trustsec_download_enviroment_data_every_x_seconds=self.trustsec_download_enviroment_data_every_x_seconds,
            trustsec_download_peer_authorization_policy_every_x_seconds=self.trustsec_download_peer_authorization_policy_every_x_seconds,
            trustsec_download_sgacl_lists_every_x_seconds=self.trustsec_download_sgacl_lists_every_x_seconds,
            trustsec_enable_mode_password=self.trustsec_enable_mode_password,
            trustsec_exec_mode_password=self.trustsec_exec_mode_password,
            trustsec_exec_mode_username=self.trustsec_exec_mode_username,
            trustsec_include_when_deploying_sgt_updates=self.trustsec_include_when_deploying_sgt_updates,
            trustsec_other_sga_devices_to_trust_this_device=self.trustsec_other_sga_devices_to_trust_this_device,
            trustsec_re_authentication_every_x_seconds=self.trustsec_re_authentication_every_x_seconds,
            trustsec_rest_api_password=self.trustsec_rest_api_password,
            trustsec_rest_api_username=self.trustsec_rest_api_username,
            trustsec_send_configuration_to_device=self.trustsec_send_configuration_to_device,
            trustsec_send_configuration_to_device_using=self.trustsec_send_configuration_to_device_using)


def get_device(id: Optional[builtins.str] = None,
               name: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDeviceResult:
    """
    This data source can read the Network Device.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.network.get_device(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the network device
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:network/getDevice:getDevice', __args__, opts=opts, typ=GetDeviceResult).value

    return AwaitableGetDeviceResult(
        authentication_dtls_required=pulumi.get(__ret__, 'authentication_dtls_required'),
        authentication_enable_key_wrap=pulumi.get(__ret__, 'authentication_enable_key_wrap'),
        authentication_enable_multi_secret=pulumi.get(__ret__, 'authentication_enable_multi_secret'),
        authentication_encryption_key=pulumi.get(__ret__, 'authentication_encryption_key'),
        authentication_encryption_key_format=pulumi.get(__ret__, 'authentication_encryption_key_format'),
        authentication_message_authenticator_code_key=pulumi.get(__ret__, 'authentication_message_authenticator_code_key'),
        authentication_network_protocol=pulumi.get(__ret__, 'authentication_network_protocol'),
        authentication_radius_shared_secret=pulumi.get(__ret__, 'authentication_radius_shared_secret'),
        authentication_second_radius_shared_secret=pulumi.get(__ret__, 'authentication_second_radius_shared_secret'),
        coa_port=pulumi.get(__ret__, 'coa_port'),
        description=pulumi.get(__ret__, 'description'),
        dtls_dns_name=pulumi.get(__ret__, 'dtls_dns_name'),
        id=pulumi.get(__ret__, 'id'),
        ips=pulumi.get(__ret__, 'ips'),
        model_name=pulumi.get(__ret__, 'model_name'),
        name=pulumi.get(__ret__, 'name'),
        network_device_groups=pulumi.get(__ret__, 'network_device_groups'),
        profile_name=pulumi.get(__ret__, 'profile_name'),
        snmp_link_trap_query=pulumi.get(__ret__, 'snmp_link_trap_query'),
        snmp_mac_trap_query=pulumi.get(__ret__, 'snmp_mac_trap_query'),
        snmp_originating_policy_service_node=pulumi.get(__ret__, 'snmp_originating_policy_service_node'),
        snmp_polling_interval=pulumi.get(__ret__, 'snmp_polling_interval'),
        snmp_ro_community=pulumi.get(__ret__, 'snmp_ro_community'),
        snmp_version=pulumi.get(__ret__, 'snmp_version'),
        software_version=pulumi.get(__ret__, 'software_version'),
        tacacs_connect_mode_options=pulumi.get(__ret__, 'tacacs_connect_mode_options'),
        tacacs_shared_secret=pulumi.get(__ret__, 'tacacs_shared_secret'),
        trustsec_coa_source_host=pulumi.get(__ret__, 'trustsec_coa_source_host'),
        trustsec_device_id=pulumi.get(__ret__, 'trustsec_device_id'),
        trustsec_device_password=pulumi.get(__ret__, 'trustsec_device_password'),
        trustsec_download_enviroment_data_every_x_seconds=pulumi.get(__ret__, 'trustsec_download_enviroment_data_every_x_seconds'),
        trustsec_download_peer_authorization_policy_every_x_seconds=pulumi.get(__ret__, 'trustsec_download_peer_authorization_policy_every_x_seconds'),
        trustsec_download_sgacl_lists_every_x_seconds=pulumi.get(__ret__, 'trustsec_download_sgacl_lists_every_x_seconds'),
        trustsec_enable_mode_password=pulumi.get(__ret__, 'trustsec_enable_mode_password'),
        trustsec_exec_mode_password=pulumi.get(__ret__, 'trustsec_exec_mode_password'),
        trustsec_exec_mode_username=pulumi.get(__ret__, 'trustsec_exec_mode_username'),
        trustsec_include_when_deploying_sgt_updates=pulumi.get(__ret__, 'trustsec_include_when_deploying_sgt_updates'),
        trustsec_other_sga_devices_to_trust_this_device=pulumi.get(__ret__, 'trustsec_other_sga_devices_to_trust_this_device'),
        trustsec_re_authentication_every_x_seconds=pulumi.get(__ret__, 'trustsec_re_authentication_every_x_seconds'),
        trustsec_rest_api_password=pulumi.get(__ret__, 'trustsec_rest_api_password'),
        trustsec_rest_api_username=pulumi.get(__ret__, 'trustsec_rest_api_username'),
        trustsec_send_configuration_to_device=pulumi.get(__ret__, 'trustsec_send_configuration_to_device'),
        trustsec_send_configuration_to_device_using=pulumi.get(__ret__, 'trustsec_send_configuration_to_device_using'))
def get_device_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDeviceResult]:
    """
    This data source can read the Network Device.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.network.get_device(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the network device
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:network/getDevice:getDevice', __args__, opts=opts, typ=GetDeviceResult)
    return __ret__.apply(lambda __response__: GetDeviceResult(
        authentication_dtls_required=pulumi.get(__response__, 'authentication_dtls_required'),
        authentication_enable_key_wrap=pulumi.get(__response__, 'authentication_enable_key_wrap'),
        authentication_enable_multi_secret=pulumi.get(__response__, 'authentication_enable_multi_secret'),
        authentication_encryption_key=pulumi.get(__response__, 'authentication_encryption_key'),
        authentication_encryption_key_format=pulumi.get(__response__, 'authentication_encryption_key_format'),
        authentication_message_authenticator_code_key=pulumi.get(__response__, 'authentication_message_authenticator_code_key'),
        authentication_network_protocol=pulumi.get(__response__, 'authentication_network_protocol'),
        authentication_radius_shared_secret=pulumi.get(__response__, 'authentication_radius_shared_secret'),
        authentication_second_radius_shared_secret=pulumi.get(__response__, 'authentication_second_radius_shared_secret'),
        coa_port=pulumi.get(__response__, 'coa_port'),
        description=pulumi.get(__response__, 'description'),
        dtls_dns_name=pulumi.get(__response__, 'dtls_dns_name'),
        id=pulumi.get(__response__, 'id'),
        ips=pulumi.get(__response__, 'ips'),
        model_name=pulumi.get(__response__, 'model_name'),
        name=pulumi.get(__response__, 'name'),
        network_device_groups=pulumi.get(__response__, 'network_device_groups'),
        profile_name=pulumi.get(__response__, 'profile_name'),
        snmp_link_trap_query=pulumi.get(__response__, 'snmp_link_trap_query'),
        snmp_mac_trap_query=pulumi.get(__response__, 'snmp_mac_trap_query'),
        snmp_originating_policy_service_node=pulumi.get(__response__, 'snmp_originating_policy_service_node'),
        snmp_polling_interval=pulumi.get(__response__, 'snmp_polling_interval'),
        snmp_ro_community=pulumi.get(__response__, 'snmp_ro_community'),
        snmp_version=pulumi.get(__response__, 'snmp_version'),
        software_version=pulumi.get(__response__, 'software_version'),
        tacacs_connect_mode_options=pulumi.get(__response__, 'tacacs_connect_mode_options'),
        tacacs_shared_secret=pulumi.get(__response__, 'tacacs_shared_secret'),
        trustsec_coa_source_host=pulumi.get(__response__, 'trustsec_coa_source_host'),
        trustsec_device_id=pulumi.get(__response__, 'trustsec_device_id'),
        trustsec_device_password=pulumi.get(__response__, 'trustsec_device_password'),
        trustsec_download_enviroment_data_every_x_seconds=pulumi.get(__response__, 'trustsec_download_enviroment_data_every_x_seconds'),
        trustsec_download_peer_authorization_policy_every_x_seconds=pulumi.get(__response__, 'trustsec_download_peer_authorization_policy_every_x_seconds'),
        trustsec_download_sgacl_lists_every_x_seconds=pulumi.get(__response__, 'trustsec_download_sgacl_lists_every_x_seconds'),
        trustsec_enable_mode_password=pulumi.get(__response__, 'trustsec_enable_mode_password'),
        trustsec_exec_mode_password=pulumi.get(__response__, 'trustsec_exec_mode_password'),
        trustsec_exec_mode_username=pulumi.get(__response__, 'trustsec_exec_mode_username'),
        trustsec_include_when_deploying_sgt_updates=pulumi.get(__response__, 'trustsec_include_when_deploying_sgt_updates'),
        trustsec_other_sga_devices_to_trust_this_device=pulumi.get(__response__, 'trustsec_other_sga_devices_to_trust_this_device'),
        trustsec_re_authentication_every_x_seconds=pulumi.get(__response__, 'trustsec_re_authentication_every_x_seconds'),
        trustsec_rest_api_password=pulumi.get(__response__, 'trustsec_rest_api_password'),
        trustsec_rest_api_username=pulumi.get(__response__, 'trustsec_rest_api_username'),
        trustsec_send_configuration_to_device=pulumi.get(__response__, 'trustsec_send_configuration_to_device'),
        trustsec_send_configuration_to_device_using=pulumi.get(__response__, 'trustsec_send_configuration_to_device_using')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetInternalUserResult',
    'AwaitableGetInternalUserResult',
    'get_internal_user',
    'get_internal_user_output',
]

@pulumi.output_type
class GetInternalUserResult:
    """
    A collection of values returned by getInternalUser.
    """
    def __init__(__self__, account_name_alias=None, change_password=None, custom_attributes=None, description=None, email=None, enable_password=None, enabled=None, first_name=None, id=None, identity_groups=None, last_name=None, name=None, password=None, password_id_store=None, password_never_expires=None):
        if account_name_alias and not isinstance(account_name_alias, str):
            raise TypeError("Expected argument 'account_name_alias' to be a str")
        pulumi.set(__self__, "account_name_alias", account_name_alias)
        if change_password and not isinstance(change_password, bool):
            raise TypeError("Expected argument 'change_password' to be a bool")
        pulumi.set(__self__, "change_password", change_password)
        if custom_attributes and not isinstance(custom_attributes, str):
            raise TypeError("Expected argument 'custom_attributes' to be a str")
        pulumi.set(__self__, "custom_attributes", custom_attributes)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if enable_password and not isinstance(enable_password, str):
            raise TypeError("Expected argument 'enable_password' to be a str")
        pulumi.set(__self__, "enable_password", enable_password)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if first_name and not isinstance(first_name, str):
            raise TypeError("Expected argument 'first_name' to be a str")
        pulumi.set(__self__, "first_name", first_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identity_groups and not isinstance(identity_groups, str):
            raise TypeError("Expected argument 'identity_groups' to be a str")
        pulumi.set(__self__, "identity_groups", identity_groups)
        if last_name and not isinstance(last_name, str):
            raise TypeError("Expected argument 'last_name' to be a str")
        pulumi.set(__self__, "last_name", last_name)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if password_id_store and not isinstance(password_id_store, str):
            raise TypeError("Expected argument 'password_id_store' to be a str")
        pulumi.set(__self__, "password_id_store", password_id_store)
        if password_never_expires and not isinstance(password_never_expires, bool):
            raise TypeError("Expected argument 'password_never_expires' to be a bool")
        pulumi.set(__self__, "password_never_expires", password_never_expires)

    @property
    @pulumi.getter(name="accountNameAlias")
    def account_name_alias(self) -> builtins.str:
        """
        The Account Name Alias will be used to send email notifications about password expiration. This field is only supported from ISE 3.2.
        """
        return pulumi.get(self, "account_name_alias")

    @property
    @pulumi.getter(name="changePassword")
    def change_password(self) -> builtins.bool:
        """
        Requires the user to change the password
        """
        return pulumi.get(self, "change_password")

    @property
    @pulumi.getter(name="customAttributes")
    def custom_attributes(self) -> builtins.str:
        """
        Key value map
        """
        return pulumi.get(self, "custom_attributes")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        Email address
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="enablePassword")
    def enable_password(self) -> builtins.str:
        """
        This field is added in ISE 2.0 to support TACACS+
        """
        return pulumi.get(self, "enable_password")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        Whether the user is enabled/disabled
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> builtins.str:
        """
        First name of the internal user
        """
        return pulumi.get(self, "first_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="identityGroups")
    def identity_groups(self) -> builtins.str:
        """
        Comma separated list of identity group IDs.
        """
        return pulumi.get(self, "identity_groups")

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> builtins.str:
        """
        Last name of the internal user
        """
        return pulumi.get(self, "last_name")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the internal user
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> builtins.str:
        """
        The password of the internal user
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordIdStore")
    def password_id_store(self) -> builtins.str:
        """
        The ID store where the internal user's password is kept
        """
        return pulumi.get(self, "password_id_store")

    @property
    @pulumi.getter(name="passwordNeverExpires")
    def password_never_expires(self) -> builtins.bool:
        """
        Set to `true` to indicate the user password never expires. This will not apply to Users who are also ISE Admins. This field is only supported from ISE 3.2.
        """
        return pulumi.get(self, "password_never_expires")


class AwaitableGetInternalUserResult(GetInternalUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInternalUserResult(
            account_name_alias=self.account_name_alias,
            change_password=self.change_password,
            custom_attributes=self.custom_attributes,
            description=self.description,
            email=self.email,
            enable_password=self.enable_password,
            enabled=self.enabled,
            first_name=self.first_name,
            id=self.id,
            identity_groups=self.identity_groups,
            last_name=self.last_name,
            name=self.name,
            password=self.password,
            password_id_store=self.password_id_store,
            password_never_expires=self.password_never_expires)


def get_internal_user(id: Optional[builtins.str] = None,
                      name: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInternalUserResult:
    """
    This data source can read the Internal User.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_internal_user(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the internal user
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:identitymanagement/getInternalUser:getInternalUser', __args__, opts=opts, typ=GetInternalUserResult).value

    return AwaitableGetInternalUserResult(
        account_name_alias=pulumi.get(__ret__, 'account_name_alias'),
        change_password=pulumi.get(__ret__, 'change_password'),
        custom_attributes=pulumi.get(__ret__, 'custom_attributes'),
        description=pulumi.get(__ret__, 'description'),
        email=pulumi.get(__ret__, 'email'),
        enable_password=pulumi.get(__ret__, 'enable_password'),
        enabled=pulumi.get(__ret__, 'enabled'),
        first_name=pulumi.get(__ret__, 'first_name'),
        id=pulumi.get(__ret__, 'id'),
        identity_groups=pulumi.get(__ret__, 'identity_groups'),
        last_name=pulumi.get(__ret__, 'last_name'),
        name=pulumi.get(__ret__, 'name'),
        password=pulumi.get(__ret__, 'password'),
        password_id_store=pulumi.get(__ret__, 'password_id_store'),
        password_never_expires=pulumi.get(__ret__, 'password_never_expires'))
def get_internal_user_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInternalUserResult]:
    """
    This data source can read the Internal User.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.identitymanagement.get_internal_user(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: The name of the internal user
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:identitymanagement/getInternalUser:getInternalUser', __args__, opts=opts, typ=GetInternalUserResult)
    return __ret__.apply(lambda __response__: GetInternalUserResult(
        account_name_alias=pulumi.get(__response__, 'account_name_alias'),
        change_password=pulumi.get(__response__, 'change_password'),
        custom_attributes=pulumi.get(__response__, 'custom_attributes'),
        description=pulumi.get(__response__, 'description'),
        email=pulumi.get(__response__, 'email'),
        enable_password=pulumi.get(__response__, 'enable_password'),
        enabled=pulumi.get(__response__, 'enabled'),
        first_name=pulumi.get(__response__, 'first_name'),
        id=pulumi.get(__response__, 'id'),
        identity_groups=pulumi.get(__response__, 'identity_groups'),
        last_name=pulumi.get(__response__, 'last_name'),
        name=pulumi.get(__response__, 'name'),
        password=pulumi.get(__response__, 'password'),
        password_id_store=pulumi.get(__response__, 'password_id_store'),
        password_never_expires=pulumi.get(__response__, 'password_never_expires')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSxpDomainFilterResult',
    'AwaitableGetSxpDomainFilterResult',
    'get_sxp_domain_filter',
    'get_sxp_domain_filter_output',
]

@pulumi.output_type
class GetSxpDomainFilterResult:
    """
    A collection of values returned by getSxpDomainFilter.
    """
    def __init__(__self__, description=None, domains=None, id=None, name=None, sgt=None, subnet=None, vn=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if domains and not isinstance(domains, str):
            raise TypeError("Expected argument 'domains' to be a str")
        pulumi.set(__self__, "domains", domains)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if sgt and not isinstance(sgt, str):
            raise TypeError("Expected argument 'sgt' to be a str")
        pulumi.set(__self__, "sgt", sgt)
        if subnet and not isinstance(subnet, str):
            raise TypeError("Expected argument 'subnet' to be a str")
        pulumi.set(__self__, "subnet", subnet)
        if vn and not isinstance(vn, str):
            raise TypeError("Expected argument 'vn' to be a str")
        pulumi.set(__self__, "vn", vn)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def domains(self) -> builtins.str:
        """
        List of SXP Domains, separated with comma
        """
        return pulumi.get(self, "domains")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Resource name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def sgt(self) -> builtins.str:
        """
        SGT name or ID. At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "sgt")

    @property
    @pulumi.getter
    def subnet(self) -> builtins.str:
        """
        Subnet for filter policy (hostname is not supported). At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter
    def vn(self) -> builtins.str:
        """
        Virtual Network. At least one of subnet or sgt or vn should be defined
        """
        return pulumi.get(self, "vn")


class AwaitableGetSxpDomainFilterResult(GetSxpDomainFilterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSxpDomainFilterResult(
            description=self.description,
            domains=self.domains,
            id=self.id,
            name=self.name,
            sgt=self.sgt,
            subnet=self.subnet,
            vn=self.vn)


def get_sxp_domain_filter(id: Optional[builtins.str] = None,
                          name: Optional[builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSxpDomainFilterResult:
    """
    This data source can read the SXP Domain Filter.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_sxp_domain_filter(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: Resource name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:trustsec/getSxpDomainFilter:getSxpDomainFilter', __args__, opts=opts, typ=GetSxpDomainFilterResult).value

    return AwaitableGetSxpDomainFilterResult(
        description=pulumi.get(__ret__, 'description'),
        domains=pulumi.get(__ret__, 'domains'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        sgt=pulumi.get(__ret__, 'sgt'),
        subnet=pulumi.get(__ret__, 'subnet'),
        vn=pulumi.get(__ret__, 'vn'))
def get_sxp_domain_filter_output(id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSxpDomainFilterResult]:
    """
    This data source can read the SXP Domain Filter.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_sxp_domain_filter(id="76d24097-41c4-4558-a4d0-a8c07ac08470")
    ```


    :param builtins.str id: The id of the object
    :param builtins.str name: Resource name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:trustsec/getSxpDomainFilter:getSxpDomainFilter', __args__, opts=opts, typ=GetSxpDomainFilterResult)
    return __ret__.apply(lambda __response__: GetSxpDomainFilterResult(
        description=pulumi.get(__response__, 'description'),
        domains=pulumi.get(__response__, 'domains'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        sgt=pulumi.get(__response__, 'sgt'),
        subnet=pulumi.get(__response__, 'subnet'),
        vn=pulumi.get(__response__, 'vn')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TimeAndDateConditionArgs', 'TimeAndDateCondition']

@pulumi.input_type
class TimeAndDateConditionArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 end_date: Optional[pulumi.Input[builtins.str]] = None,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 exception_end_date: Optional[pulumi.Input[builtins.str]] = None,
                 exception_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 exception_start_date: Optional[pulumi.Input[builtins.str]] = None,
                 exception_start_time: Optional[pulumi.Input[builtins.str]] = None,
                 is_negate: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 start_date: Optional[pulumi.Input[builtins.str]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None,
                 week_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 week_days_exceptions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a TimeAndDateCondition resource.
        :param pulumi.Input[builtins.str] description: Condition description
        :param pulumi.Input[builtins.str] end_date: End date
        :param pulumi.Input[builtins.str] end_time: End time
        :param pulumi.Input[builtins.str] exception_end_date: Exception end date
        :param pulumi.Input[builtins.str] exception_end_time: Exception end time
        :param pulumi.Input[builtins.str] exception_start_date: Exception start date
        :param pulumi.Input[builtins.str] exception_start_time: Exception start time
        :param pulumi.Input[builtins.bool] is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[builtins.str] name: Condition name
        :param pulumi.Input[builtins.str] start_date: Start date
        :param pulumi.Input[builtins.str] start_time: Start time
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] week_days: Defines for which days this condition will be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`. Default - List of all week days.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] week_days_exceptions: Defines for which days this condition will NOT be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if end_date is not None:
            pulumi.set(__self__, "end_date", end_date)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if exception_end_date is not None:
            pulumi.set(__self__, "exception_end_date", exception_end_date)
        if exception_end_time is not None:
            pulumi.set(__self__, "exception_end_time", exception_end_time)
        if exception_start_date is not None:
            pulumi.set(__self__, "exception_start_date", exception_start_date)
        if exception_start_time is not None:
            pulumi.set(__self__, "exception_start_time", exception_start_time)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if start_date is not None:
            pulumi.set(__self__, "start_date", start_date)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if week_days is not None:
            pulumi.set(__self__, "week_days", week_days)
        if week_days_exceptions is not None:
            pulumi.set(__self__, "week_days_exceptions", week_days_exceptions)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        End date
        """
        return pulumi.get(self, "end_date")

    @end_date.setter
    def end_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_date", value)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        End time
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter(name="exceptionEndDate")
    def exception_end_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Exception end date
        """
        return pulumi.get(self, "exception_end_date")

    @exception_end_date.setter
    def exception_end_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exception_end_date", value)

    @property
    @pulumi.getter(name="exceptionEndTime")
    def exception_end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Exception end time
        """
        return pulumi.get(self, "exception_end_time")

    @exception_end_time.setter
    def exception_end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exception_end_time", value)

    @property
    @pulumi.getter(name="exceptionStartDate")
    def exception_start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Exception start date
        """
        return pulumi.get(self, "exception_start_date")

    @exception_start_date.setter
    def exception_start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exception_start_date", value)

    @property
    @pulumi.getter(name="exceptionStartTime")
    def exception_start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Exception start time
        """
        return pulumi.get(self, "exception_start_time")

    @exception_start_time.setter
    def exception_start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exception_start_time", value)

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @is_negate.setter
    def is_negate(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_negate", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Start date
        """
        return pulumi.get(self, "start_date")

    @start_date.setter
    def start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_date", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Start time
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter(name="weekDays")
    def week_days(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Defines for which days this condition will be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`. Default - List of all week days.
        """
        return pulumi.get(self, "week_days")

    @week_days.setter
    def week_days(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "week_days", value)

    @property
    @pulumi.getter(name="weekDaysExceptions")
    def week_days_exceptions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Defines for which days this condition will NOT be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`.
        """
        return pulumi.get(self, "week_days_exceptions")

    @week_days_exceptions.setter
    def week_days_exceptions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "week_days_exceptions", value)


@pulumi.input_type
class _TimeAndDateConditionState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 end_date: Optional[pulumi.Input[builtins.str]] = None,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 exception_end_date: Optional[pulumi.Input[builtins.str]] = None,
                 exception_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 exception_start_date: Optional[pulumi.Input[builtins.str]] = None,
                 exception_start_time: Optional[pulumi.Input[builtins.str]] = None,
                 is_negate: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 start_date: Optional[pulumi.Input[builtins.str]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None,
                 week_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 week_days_exceptions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering TimeAndDateCondition resources.
        :param pulumi.Input[builtins.str] description: Condition description
        :param pulumi.Input[builtins.str] end_date: End date
        :param pulumi.Input[builtins.str] end_time: End time
        :param pulumi.Input[builtins.str] exception_end_date: Exception end date
        :param pulumi.Input[builtins.str] exception_end_time: Exception end time
        :param pulumi.Input[builtins.str] exception_start_date: Exception start date
        :param pulumi.Input[builtins.str] exception_start_time: Exception start time
        :param pulumi.Input[builtins.bool] is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[builtins.str] name: Condition name
        :param pulumi.Input[builtins.str] start_date: Start date
        :param pulumi.Input[builtins.str] start_time: Start time
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] week_days: Defines for which days this condition will be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`. Default - List of all week days.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] week_days_exceptions: Defines for which days this condition will NOT be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if end_date is not None:
            pulumi.set(__self__, "end_date", end_date)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if exception_end_date is not None:
            pulumi.set(__self__, "exception_end_date", exception_end_date)
        if exception_end_time is not None:
            pulumi.set(__self__, "exception_end_time", exception_end_time)
        if exception_start_date is not None:
            pulumi.set(__self__, "exception_start_date", exception_start_date)
        if exception_start_time is not None:
            pulumi.set(__self__, "exception_start_time", exception_start_time)
        if is_negate is not None:
            pulumi.set(__self__, "is_negate", is_negate)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if start_date is not None:
            pulumi.set(__self__, "start_date", start_date)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if week_days is not None:
            pulumi.set(__self__, "week_days", week_days)
        if week_days_exceptions is not None:
            pulumi.set(__self__, "week_days_exceptions", week_days_exceptions)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        End date
        """
        return pulumi.get(self, "end_date")

    @end_date.setter
    def end_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_date", value)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        End time
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter(name="exceptionEndDate")
    def exception_end_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Exception end date
        """
        return pulumi.get(self, "exception_end_date")

    @exception_end_date.setter
    def exception_end_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exception_end_date", value)

    @property
    @pulumi.getter(name="exceptionEndTime")
    def exception_end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Exception end time
        """
        return pulumi.get(self, "exception_end_time")

    @exception_end_time.setter
    def exception_end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exception_end_time", value)

    @property
    @pulumi.getter(name="exceptionStartDate")
    def exception_start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Exception start date
        """
        return pulumi.get(self, "exception_start_date")

    @exception_start_date.setter
    def exception_start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exception_start_date", value)

    @property
    @pulumi.getter(name="exceptionStartTime")
    def exception_start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Exception start time
        """
        return pulumi.get(self, "exception_start_time")

    @exception_start_time.setter
    def exception_start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exception_start_time", value)

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @is_negate.setter
    def is_negate(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_negate", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Start date
        """
        return pulumi.get(self, "start_date")

    @start_date.setter
    def start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_date", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Start time
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter(name="weekDays")
    def week_days(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Defines for which days this condition will be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`. Default - List of all week days.
        """
        return pulumi.get(self, "week_days")

    @week_days.setter
    def week_days(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "week_days", value)

    @property
    @pulumi.getter(name="weekDaysExceptions")
    def week_days_exceptions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Defines for which days this condition will NOT be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`.
        """
        return pulumi.get(self, "week_days_exceptions")

    @week_days_exceptions.setter
    def week_days_exceptions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "week_days_exceptions", value)


class TimeAndDateCondition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 end_date: Optional[pulumi.Input[builtins.str]] = None,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 exception_end_date: Optional[pulumi.Input[builtins.str]] = None,
                 exception_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 exception_start_date: Optional[pulumi.Input[builtins.str]] = None,
                 exception_start_time: Optional[pulumi.Input[builtins.str]] = None,
                 is_negate: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 start_date: Optional[pulumi.Input[builtins.str]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None,
                 week_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 week_days_exceptions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        This resource can manage a Network Access Time And Date Condition.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.networkaccess.TimeAndDateCondition("example",
            name="Cond1",
            description="My description",
            is_negate=False,
            week_days=["Monday"],
            week_days_exceptions=["Tuesday"],
            start_date="2022-05-06",
            end_date="2022-05-10",
            exception_start_date="2022-06-06",
            exception_end_date="2022-06-10",
            start_time="08:00",
            end_time="15:00",
            exception_start_time="20:00",
            exception_end_time="22:00")
        ```

        ## Import

        ```sh
        $ pulumi import ise:networkaccess/timeAndDateCondition:TimeAndDateCondition example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Condition description
        :param pulumi.Input[builtins.str] end_date: End date
        :param pulumi.Input[builtins.str] end_time: End time
        :param pulumi.Input[builtins.str] exception_end_date: Exception end date
        :param pulumi.Input[builtins.str] exception_end_time: Exception end time
        :param pulumi.Input[builtins.str] exception_start_date: Exception start date
        :param pulumi.Input[builtins.str] exception_start_time: Exception start time
        :param pulumi.Input[builtins.bool] is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[builtins.str] name: Condition name
        :param pulumi.Input[builtins.str] start_date: Start date
        :param pulumi.Input[builtins.str] start_time: Start time
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] week_days: Defines for which days this condition will be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`. Default - List of all week days.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] week_days_exceptions: Defines for which days this condition will NOT be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TimeAndDateConditionArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a Network Access Time And Date Condition.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.networkaccess.TimeAndDateCondition("example",
            name="Cond1",
            description="My description",
            is_negate=False,
            week_days=["Monday"],
            week_days_exceptions=["Tuesday"],
            start_date="2022-05-06",
            end_date="2022-05-10",
            exception_start_date="2022-06-06",
            exception_end_date="2022-06-10",
            start_time="08:00",
            end_time="15:00",
            exception_start_time="20:00",
            exception_end_time="22:00")
        ```

        ## Import

        ```sh
        $ pulumi import ise:networkaccess/timeAndDateCondition:TimeAndDateCondition example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param TimeAndDateConditionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TimeAndDateConditionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 end_date: Optional[pulumi.Input[builtins.str]] = None,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 exception_end_date: Optional[pulumi.Input[builtins.str]] = None,
                 exception_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 exception_start_date: Optional[pulumi.Input[builtins.str]] = None,
                 exception_start_time: Optional[pulumi.Input[builtins.str]] = None,
                 is_negate: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 start_date: Optional[pulumi.Input[builtins.str]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None,
                 week_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 week_days_exceptions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TimeAndDateConditionArgs.__new__(TimeAndDateConditionArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["end_date"] = end_date
            __props__.__dict__["end_time"] = end_time
            __props__.__dict__["exception_end_date"] = exception_end_date
            __props__.__dict__["exception_end_time"] = exception_end_time
            __props__.__dict__["exception_start_date"] = exception_start_date
            __props__.__dict__["exception_start_time"] = exception_start_time
            __props__.__dict__["is_negate"] = is_negate
            __props__.__dict__["name"] = name
            __props__.__dict__["start_date"] = start_date
            __props__.__dict__["start_time"] = start_time
            __props__.__dict__["week_days"] = week_days
            __props__.__dict__["week_days_exceptions"] = week_days_exceptions
        super(TimeAndDateCondition, __self__).__init__(
            'ise:networkaccess/timeAndDateCondition:TimeAndDateCondition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            end_date: Optional[pulumi.Input[builtins.str]] = None,
            end_time: Optional[pulumi.Input[builtins.str]] = None,
            exception_end_date: Optional[pulumi.Input[builtins.str]] = None,
            exception_end_time: Optional[pulumi.Input[builtins.str]] = None,
            exception_start_date: Optional[pulumi.Input[builtins.str]] = None,
            exception_start_time: Optional[pulumi.Input[builtins.str]] = None,
            is_negate: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            start_date: Optional[pulumi.Input[builtins.str]] = None,
            start_time: Optional[pulumi.Input[builtins.str]] = None,
            week_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            week_days_exceptions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'TimeAndDateCondition':
        """
        Get an existing TimeAndDateCondition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Condition description
        :param pulumi.Input[builtins.str] end_date: End date
        :param pulumi.Input[builtins.str] end_time: End time
        :param pulumi.Input[builtins.str] exception_end_date: Exception end date
        :param pulumi.Input[builtins.str] exception_end_time: Exception end time
        :param pulumi.Input[builtins.str] exception_start_date: Exception start date
        :param pulumi.Input[builtins.str] exception_start_time: Exception start time
        :param pulumi.Input[builtins.bool] is_negate: Indicates whereas this condition is in negate mode
        :param pulumi.Input[builtins.str] name: Condition name
        :param pulumi.Input[builtins.str] start_date: Start date
        :param pulumi.Input[builtins.str] start_time: Start time
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] week_days: Defines for which days this condition will be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`. Default - List of all week days.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] week_days_exceptions: Defines for which days this condition will NOT be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TimeAndDateConditionState.__new__(_TimeAndDateConditionState)

        __props__.__dict__["description"] = description
        __props__.__dict__["end_date"] = end_date
        __props__.__dict__["end_time"] = end_time
        __props__.__dict__["exception_end_date"] = exception_end_date
        __props__.__dict__["exception_end_time"] = exception_end_time
        __props__.__dict__["exception_start_date"] = exception_start_date
        __props__.__dict__["exception_start_time"] = exception_start_time
        __props__.__dict__["is_negate"] = is_negate
        __props__.__dict__["name"] = name
        __props__.__dict__["start_date"] = start_date
        __props__.__dict__["start_time"] = start_time
        __props__.__dict__["week_days"] = week_days
        __props__.__dict__["week_days_exceptions"] = week_days_exceptions
        return TimeAndDateCondition(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Condition description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        End date
        """
        return pulumi.get(self, "end_date")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        End time
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="exceptionEndDate")
    def exception_end_date(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Exception end date
        """
        return pulumi.get(self, "exception_end_date")

    @property
    @pulumi.getter(name="exceptionEndTime")
    def exception_end_time(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Exception end time
        """
        return pulumi.get(self, "exception_end_time")

    @property
    @pulumi.getter(name="exceptionStartDate")
    def exception_start_date(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Exception start date
        """
        return pulumi.get(self, "exception_start_date")

    @property
    @pulumi.getter(name="exceptionStartTime")
    def exception_start_time(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Exception start time
        """
        return pulumi.get(self, "exception_start_time")

    @property
    @pulumi.getter(name="isNegate")
    def is_negate(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Indicates whereas this condition is in negate mode
        """
        return pulumi.get(self, "is_negate")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Condition name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Start date
        """
        return pulumi.get(self, "start_date")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Start time
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter(name="weekDays")
    def week_days(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Defines for which days this condition will be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`. Default - List of all week days.
        """
        return pulumi.get(self, "week_days")

    @property
    @pulumi.getter(name="weekDaysExceptions")
    def week_days_exceptions(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Defines for which days this condition will NOT be matched. List of weekdays - `Monday`, `Tuesday`, `Wednesday`, `Thursday`, `Friday`, `Saturday`, `Sunday`.
        """
        return pulumi.get(self, "week_days_exceptions")

